@@ -2,4 +2,8 @@
 you can perform with the API of the visual analytics tool by Berlin United for the Robocup SPL"""
 
 
-__version__ = "0.4.1"
+__version__ = "0.6.3"
+
+__pdoc__ = {
+    'core': False,  # Excludes the entire module/folder
+}
\ No newline at end of file
