@@ -6,23 +6,17 @@ from ..core.pydantic_utilities import deep_union_pydantic_dicts, pydantic_v1
 
 
 class BehaviorOptions(pydantic_v1.BaseModel):
-    """
-    Id assigned by django
-    """
+
+    #: Id assigned by django
     id: typing.Optional[int] = None
 
-    """
-    Log ID: Id of related log / robot data
-    """
+    #: Log ID: Id of related log / robot data
     log_id: typing.Optional[int] = pydantic_v1.Field(default=None)
 
-    """
-    xabsl_internal_option_id
-    """
+    #: xabsl_internal_option_id
     xabsl_internal_option_id: typing.Optional[int] = pydantic_v1.Field(default=None)
-    """
-    option_name
-    """
+
+    #: option_name
     option_name: typing.Optional[str] = pydantic_v1.Field(default=None)
 
     def json(self, **kwargs: typing.Any) -> str:
