@@ -6,34 +6,13 @@ from ..core.pydantic_utilities import deep_union_pydantic_dicts, pydantic_v1
 
 
 class MotionRepresentation(pydantic_v1.BaseModel):
-    """
-    Id assigned by django
-    """
+    #: Id assigned by django
     id: typing.Optional[int] = None
 
-    """
-    Log ID: Id of related log / robot data
-    """
-    log_id: typing.Optional[int] = pydantic_v1.Field(default=None)
+    #: reference to a specific motion frame
+    frame: typing.Optional[int] = pydantic_v1.Field(default=None)
     
-    """
-    Frame Number from sensor.log
-    """
-    sensor_frame_number: typing.Optional[int] = None
-
-    """
-    sensor_frame_time
-    """
-    sensor_frame_time: typing.Optional[int] = None
-
-    """
-    representation_name
-    """
-    representation_name: typing.Optional[str] = pydantic_v1.Field(default=None)
-
-    """
-    representation_data
-    """
+    #: representation_data
     representation_data: typing.Optional[typing.Dict[str, typing.Any]] = pydantic_v1.Field(default=None)
 
     def json(self, **kwargs: typing.Any) -> str:
