@@ -6,24 +6,16 @@ from ..core.pydantic_utilities import deep_union_pydantic_dicts, pydantic_v1
 
 
 class XabslSymbolSparse(pydantic_v1.BaseModel):
-    """
-    Id assigned by django
-    """
+    #: Id assigned by django
     id: typing.Optional[int] = None
 
-    """
-    Foreign key to the log 
-    """
+    #: Foreign key to the log 
     log_id: typing.Optional[int] = pydantic_v1.Field(default=None)
     
-    """
-    frame
-    """
+    #: frame
     frame: typing.Optional[int] = None
 
-    """
-    data
-    """
+    #: data
     data: typing.Optional[typing.Dict[str, typing.Any]] = pydantic_v1.Field(default=None)
 
 
